/*

  File: OTMathPipes.h
  Authors: Bergerson & Cone
  Generated: July 14, 1990
  Modification History:

  9/4/90 - Eric Bergerson

           Added delegate.
  
           Converted private IB addMessage:from:type: method to
	   delegate method kernelDidMsg:from:type:

	   Added user methods commandReturns: and statusDidChange:
	   as delegate styled methods called on user

	   Added status message type MP_DIED for when a kernel dies.
*/
/*
Copyright (c) 1990 Objective Technologies, Inc.
All rights reserved.
*/

#import <objc/Object.h>
#import <dpsclient/dpsclient.h>

/* Available pipe fd's */
#define MP_RR 0
#define MP_RW 1
#define MP_WR 2
#define MP_WW 3
#define MP_NOPIPE -1

/* Available pipe sets */
#define MP_READPIPES 0
#define MP_WRITEPIPES 1

/* Default Values */
#define MP_DEFAULT_ARGC 5
#define MP_BUF_SIZE 1024
#define MP_DEFAULT_DELAY 5

/* Status message types */
#define MP_SENDING 0
#define MP_TIMINGOUT 1
#define MP_RECEIVING 2
#define MP_DONE 3
#define MP_DIED 4

/* Type definitions for kernel monitoring */
#define MP_MSG 0
#define MP_RESPONSE 1
#define MP_PACKET 2

/* Type definitions for error conditions */
#define MP_READPIPES_ERR 1
#define MP_WRITEPIPES_ERR 2
#define MP_TERMINATE_ERR 3
#define MP_KERNELDEATH_ERR 4
#define MP_CANTPROCESS_ERR 5

/* Mathematica Version Control */
#define MP_VERDEFAULT 0
#define MP_VER1DOT2 1
#define MP_VER2DOT0 2

@interface OTMathPipes: Object
{
  int pipes[4];

  char *path;
  int argc;
  char **argv;

  int pid;

  id user;

  DPSTimedEntry teNumber;

  double delay;

  char *response;

  id delegate;

  id errorDelegate;
}

+ initialize;

- init;
- free;

- (int) pipeFd: (int) anFd;
- getPipeFds: (int *) anFdArray;
- (BOOL) makePipe: (int) somePipeSet;

- (const char *) path;
- setPath: (const char *) aNewPath;
- (int) argc;
- (char **) argv;
- setArgc: (int) ac Argv: (char **) av;

- startKernel;
- terminateKernel;
- kernelDiedCleanup;
- (BOOL) kernelRunning;
- (int) pid;

- user;
- setUser: sender;

- (DPSTimedEntry) teNumber;
- setTeNumber: (DPSTimedEntry) aTeNumber;

- (double) delay;
- setDelay: (double) wait;

- writeString: (const char *) aString timeout: (double) aDelay from:aUser;
- writeString: (const char *) aString timeout: (double) aDelay from:aUser notify:(BOOL) flag;

- (const char *) response;
- setResponse: (const char *) aResponse;
- concatResponse: (const char *) moreData;

- delegate;
- setDelegate: sender;

/* error handling methods */
- setErrorDelegate:aDelegate;
- errorDelegate;
- (const char *)strerror:(int)errorNum;

/* error delegate may implement */
- (BOOL) errorDidOccur:(int)errorNum from:anObject;
- showError:(const char *)errorMessage;

/* delegate may implement */
- kernelDidMsg: (const char *) aMsg from: anOTMathPipes type:(int) msgType;

/* user receives these messages */
- commandReturns: (const char *) aResponse;
- statusDidChange: anOTMathPipes to: (int)statusValue;



@end
