/*

  File: OTProcessor.h
  Authors: Bergerson & Cone
  Generated: July 14, 1990
  Modification History:

  version 14 - added mathVersion control
    Feb 8, 1992
*/
/*
Copyright (c) 1990 Objective Technologies, Inc.
All rights reserved.
*/

#import <appkit/Button.h>



/* Command types */
#define MA_WAIT_UNTIL_ANSWERED -2
#define MA_NODIRECT -1
#define MA_RESULT 0
#define MA_EXPRESSION 1
#define MA_POSTSCRIPT 2

/* Outbound packet packaging formats */
#define MA_RESULT_PACKAGE "If[NumberQ[objtechmath = %s],CForm[N[objtechmath]],NaN]\n"
#define MA_RP_LEN 54
#define MA_EXPRESSION_PACKAGE "%s\n"
#define MA_EP_LEN 1
#define MA_POSTSCRIPT_PACKAGE "Display[\"stdout\",%s]\n"
#define MA_PP_LEN 19

/* Status alert types */
#define MA_DONT_ALERT 0
#define MA_DISABLE 1
#define MA_DISABLE_AND_MESSAGE 2

/* Load from editor functions */
#define MA_ON_MSG_ONLY 0 
#define MA_ON_LAUNCH 1
#define MA_ON_LAUNCH_AND_PROCESS 2

// Version 14 was the 2.1B2 version -- Mathematica 1.2 still supported in inspector
#define OTPROCESSOR_CURRENT_VERSION 15

@interface OTProcessor: Button 
{

  id mathPipes;	      
  id commandEditor;   
  int commandType;    

  char *command;      
  char *response;     

  id graph;	      
  id expression;      
  id result;	      

  int waitingOn;      
  double delay;	      

  int loadFromEditor; 
  int statusAlert;    

  id delegate;	      
}

+ initialize;
+ launchCommonMathKernel; 
+ terminateCommonMathKernel;

- initFrame: (const NXRect *) r;
- initWithoutPipes: (const NXRect *)r;
- free;

- startKernel;
- killKernel;
- launchMath: sender;
- terminateMath: sender;
- (BOOL) kernelRunning;

- pipes;
- setPipes: newPipes;

- (int) commandType; 
- setCommandType: (int) aType;

- takeTagForTypeFrom: sender;
- takeIntForTypeFrom: sender;

- (const char *) command;
- setCommand: (const char *) aCommand;
- concatCommand: (const char *) aCommand;
- takeCommandFrom: sender;
- takeCommandFromNewDelegate: sender;
- takeCommandFromEditor: sender;

- (const char *) response;
- setResponse: (const char *) aResponse;

- commandEditor;
- setCommandEditor: anObject;
- processCommand: sender;
- processCommandAs: (int) aType; 
- processToGraph: sender;
- processToExpression: sender;
- processToResult: sender;

- (int) waitingOn; 
- setWaitingOn: (int) aResultType;

- (double) delay;
- setDelay: (double) aDelay;

- (int) loadFromEditor;
- setLoadFromEditor: (int) when;

- (int) statusAlert;
- setStatusAlert: (int) type;

- delegate;
- setDelegate: anObject;

- graph;
- setGraph: anObject;
- expression;
- setExpression: anObject;
- result;
- setResult: anObject;

- (const char *) packageCommand;
- cleanCommand;
- cleanResponseForGraph;

- processOutGoing;


- write: (NXTypedStream *) s;
- read: (NXTypedStream *) s;
- (const char *) inspectorName;

/* user messages received from MathPipes */
- commandReturns: (const char *) aResponse;

/* delegate method received from MathPipes */ 
- statusDidChange:aMathPipes to: (int)statusValue;

/* sent to delegate for the error text */
- (const char *) resultErrorText;

/*
 * TYPE: Delegate; Returns the text for incorrect numeric result
 *
 */


@end


